@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 DataSync Utilities
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
 import warnings
 
@@ -134,7 +132,7 @@ def next_batch_id(session):
     a watcher thread.
     """
     sql = "select nextval('datasync_change_batch_id_seq')"
-    return session.execute(sql).scalar()
+    return session.execute(sa.text(sql)).scalar()
 
 
 def purge_datasync_settings(config, session):
