@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,14 +24,11 @@
 Data Changes Interface
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import logging
 
 from packaging.version import parse as parse_version
 import sqlalchemy as sa
 from sqlalchemy.orm import object_mapper, RelationshipProperty
-from sqlalchemy.orm.interfaces import SessionExtension
 from sqlalchemy.orm.session import Session
 
 try:
@@ -309,17 +306,21 @@ class ChangeRecorder(object):
         log.error("unexpected scenario; generated new UUID for instance: {0}".format(repr(instance)))
 
 
-class ChangeRecorderExtension(SessionExtension):
-    """
-    Session extension for recording changes.
+if parse_version(sa.__version__) < parse_version('1.4'): # pre-1.4
 
-    .. note::
-       This is only used when the installed SQLAlchemy version is old enough
-       not to support the new event interfaces.
-    """
+    from sqlalchemy.orm.interfaces import SessionExtension
 
-    def __init__(self, recorder):
-        self.recorder = recorder
+    class ChangeRecorderExtension(SessionExtension):
+        """
+        Session extension for recording changes.
 
-    def before_flush(self, session, flush_context, instances):
-        self.recorder(session, flush_context, instances)
+        .. note::
+           This is only used when the installed SQLAlchemy version is old enough
+           not to support the new event interfaces.
+        """
+
+        def __init__(self, recorder):
+            self.recorder = recorder
+
+        def before_flush(self, session, flush_context, instances):
+            self.recorder(session, flush_context, instances)
