@@ -58,7 +58,7 @@ class DatabaseHandler(GenericHandler):
         # to have config path available within the alembic `env.py`
         # script.  to my knowledge alembic itself does not need the
         # file path, but rattail gets it from alembic config, so...
-        alembic_config.config_file_name = self.config.files_read[0]
+        alembic_config.config_file_name = self.config.files_read[-1]
 
         alembic_config.set_main_option(
             'script_location',
