@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Rattail data models
 """
 
-from __future__ import unicode_literals, absolute_import
-
 from .core import Base, ModelBase, uuid_column, getset_factory, GPCType, Setting, Change, Note
 from .contact import PhoneNumber, EmailAddress, MailingAddress
 
@@ -50,7 +48,7 @@ from .employees import (Employee, EmployeePhoneNumber, EmployeeEmailAddress,
                         EmployeeStore, EmployeeDepartment, EmployeeHistory)
 from .shifts import ScheduledShift, WorkedShift
 
-from .vendors import Vendor, VendorPhoneNumber, VendorEmailAddress, VendorContact
+from .vendors import Vendor, VendorPhoneNumber, VendorEmailAddress, VendorContact, VendorSampleFile
 from .products import (UnitOfMeasure, Brand, Tax, Product, ProductImage, ProductCode,
                        ProductCost, ProductFutureCost, ProductPrice,
                        ProductInventory, ProductStoreInfo, ProductVolatile,
