@@ -27,14 +27,11 @@ Actually the classes in this module are not true models but rather are mixins,
 which provide the common columns etc. for batch tables.
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import os
 import datetime
 import shutil
 import warnings
 
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.orm import relationship, object_session
@@ -47,7 +44,6 @@ from rattail.db.model import User, Product
 from rattail.time import make_utc
 
 
-@six.python_2_unicode_compatible
 class BatchMixin(object):
     """
     Mixin for all (new-style) batch classes.
@@ -454,6 +450,7 @@ class ProductBatchRowMixin(BatchRowMixin):
             """,
             backref=orm.backref(
                 '_{}_rows'.format(table_name),
+                cascade_backrefs=False,
                 doc="""
                 Sequence of all {} rows which reference the product.
                 """.format(model_title)))
