@@ -136,7 +136,7 @@ class VendorCatalogBatchRow(ProductBatchRowMixin, Base):
     of the :attr:`ProductCost.code` column.
     """)
 
-    case_size = sa.Column(sa.Integer(), nullable=False, default=1, doc="""
+    case_size = sa.Column(sa.Numeric(precision=9, scale=4), nullable=False, default=1, doc="""
     Number of units in a case of product.
     """)
 
@@ -152,7 +152,7 @@ class VendorCatalogBatchRow(ProductBatchRowMixin, Base):
     Original vendor code for the product, if any.
     """)
 
-    old_case_size = sa.Column(sa.Integer(), nullable=False, default=1, doc="""
+    old_case_size = sa.Column(sa.Numeric(precision=9, scale=4), nullable=False, default=1, doc="""
     Original case size for the product, if any.
     """)
 
