@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,14 +24,14 @@
 Core Data Models
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import re
 
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
-from sqlalchemy.ext.declarative import declarative_base
+try:
+    from sqlalchemy.orm import declarative_base
+except ImportError:
+    from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.ext.associationproxy import association_proxy
 
 from rattail.core import Object
@@ -108,7 +108,6 @@ class ModelBase(Object):
 Base = declarative_base(cls=ModelBase)
 
 
-@six.python_2_unicode_compatible
 class Setting(Base):
     """
     Represents a "raw" config setting stored within the database.
@@ -181,7 +180,3 @@ class Note(Base):
 
     def __str__(self):
         return str(self.text)
-
-    if six.PY2:
-        def __unicode__(self):
-            return unicode(self.text)
