@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,11 +24,8 @@
 Data Models for Employees
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
 
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.ext.associationproxy import association_proxy
@@ -88,17 +85,14 @@ class Employee(Base):
     last_name = association_proxy('person', 'last_name',
                                   getset_factory=getset_factory,
                                   creator=lambda n: Person(last_name=n))
-    user = association_proxy('person', 'user')
     users = association_proxy('person', 'users')
 
-    def __str__(self):
-        if six.PY2:
-            return unicode(self).encode('utf8')
-        return str(str(self.person or "") or self.display_name or "")
+    @property
+    def user(self):
+        return self.users[0] if self.users else None
 
-    if six.PY2:
-        def __unicode__(self):
-            return unicode(str(self.person or "") or self.display_name or "")
+    def __str__(self):
+        return str(str(self.person or "") or self.display_name or "")
 
     @property
     def customers(self):
