@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,11 +24,8 @@
 Data Models for People
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
 
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.ext.declarative import declared_attr
@@ -80,19 +77,13 @@ class Person(ContactMixin, Base):
 
     modified = sa.Column(sa.DateTime(), nullable=True, onupdate=datetime.datetime.utcnow)
 
-    users = orm.relationship(
-        'User', doc="""
-        List of user accounts associated with this person.
-        """)
-
     def __str__(self):
-        if six.PY2:
-            return unicode(self).encode('utf8')
         return self.display_name or ""
 
-    if six.PY2:
-        def __unicode__(self):
-            return self.display_name or ""
+    @property
+    def user(self):
+        if self.users:
+            return self.users[0]
 
     # TODO: deprecate / remove this
     def add_email_address(self, address, type='Home', flush=False):
@@ -275,7 +266,6 @@ Person.notes = orm.relationship(
         """))
 
 
-@six.python_2_unicode_compatible
 class MergePeopleRequest(Base):
     """
     Represents a *request* to merge 2 people.  If the request is no
