@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,9 +24,6 @@
 Data Models for Vendors
 """
 
-from __future__ import unicode_literals, absolute_import
-
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.orm import relationship
@@ -38,7 +35,6 @@ from .contact import PhoneNumber, EmailAddress
 from .people import Person
 
 
-@six.python_2_unicode_compatible
 class Vendor(Base):
     """
     Represents a vendor from which products are purchased by the store.
@@ -160,7 +156,6 @@ Vendor.email = relationship(
     viewonly=True)
 
 
-@six.python_2_unicode_compatible
 class VendorContact(Base):
     """
     Represents a point of contact (e.g. salesperson) for a vendor.
@@ -209,3 +204,60 @@ Vendor._contact = relationship(
 Vendor.contact = association_proxy(
     '_contact', 'person',
     getset_factory=getset_factory)
+
+
+class VendorSampleFile(Base):
+    """
+    Contains a vendor sample file, e.g. catalog or invoice.
+    """
+    __tablename__ = 'vendor_sample_file'
+    __table_args__ = (
+        sa.ForeignKeyConstraint(['vendor_uuid'], ['vendor.uuid'],
+                                name='vendor_sample_file_fk_vendor'),
+        sa.ForeignKeyConstraint(['created_by_uuid'], ['user.uuid'],
+                                name='vendor_sample_file_fk_user'),
+    )
+    __versioned__ = {
+        'exclude': ['bytes'],
+    }
+    model_title = "Vendor Sample File"
+    model_title_plural = "Vendor Sample Files"
+
+    uuid = uuid_column()
+
+    vendor_uuid = sa.Column(sa.String(length=32), nullable=False)
+    vendor = orm.relationship(
+        'Vendor',
+        doc="""
+        Reference to the vendor associated with the sample file.
+        """)
+
+    file_type = sa.Column(sa.String(length=100), nullable=False, doc="""
+    Type of file this is, e.g. catalog or invoice.
+    """)
+
+    filename = sa.Column(sa.String(length=100), nullable=False, doc="""
+    Name of the file.
+    """)
+
+    bytes = sa.Column(sa.LargeBinary(), nullable=False, doc="""
+    Raw bytes for the file.
+    """)
+
+    effective_date = sa.Column(sa.Date(), nullable=True, doc="""
+    When the sample file becomes relevant, if applicable.
+    """)
+
+    notes = sa.Column(sa.Text(), nullable=True, doc="""
+    Arbitrary notes pertaining to the file.
+    """)
+
+    created_by_uuid = sa.Column(sa.String(length=32), nullable=False)
+    created_by = orm.relationship(
+        'User',
+        doc="""
+        Reference to the user who created the record.
+        """)
+
+    def __str__(self):
+        return self.filename or ""
