@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Email Framework
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import os
 import smtplib
 import logging
@@ -88,9 +86,16 @@ class EmailHandler(object):
     def __init__(self, config):
         self.config = config
         self.app = config.get_app()
-        self.model = self.config.get_model()
         self.enum = self.config.get_enum()
 
+        # only assign model attribute if db libs are installed
+        try:
+            import sqlalchemy
+        except ImportError:
+            pass
+        else:
+            self.model = self.config.get_model()
+
     def use_entry_points(self):
         """
         Returns a boolean indicating if the app should get its list of
@@ -275,7 +280,7 @@ class EmailHandler(object):
         session = self.app.make_session()
         attempt = session.merge(attempt)
         attempt.status_code = self.enum.EMAIL_ATTEMPT_FAILURE
-        attempt.status_text = six.text_type(error)
+        attempt.status_text = str(error)
         session.commit()
         session.close()
 
@@ -397,9 +402,16 @@ class Email(object):
     def __init__(self, config, key=None, fallback_key=None, default_subject=None):
         self.config = config
         self.app = config.get_app()
-        self.model = config.get_model()
         self.enum = config.get_enum()
 
+        # only assign model attribute if db libs are installed
+        try:
+            import sqlalchemy
+        except ImportError:
+            pass
+        else:
+            self.model = self.config.get_model()
+
         if key:
             self.key = key
         elif not self.key:
@@ -593,7 +605,7 @@ class Email(object):
     def normalize_attachments(self, attachments):
         normalized = []
         for attachment in attachments:
-            if isinstance(attachment, six.string_types):
+            if isinstance(attachment, str):
                 attachment = self.normalize_attachment(attachment)
             normalized.append(attachment)
         return normalized
